==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Soort beveiliging</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaire dns-server</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Snelheid</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Bezig met authenticeren…</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Bezig met verkrijgen van ip-adres…</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbonden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Bezig met verkrijgen van adres…</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Bekabeld netwerk: %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Draadloos netwerk: %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Bekabelde verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Bekabelde verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Draadloze verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Draadloze verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netwerk uitschakelen</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netwerkinstellingen</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dock-network-plugin/translations/dock-network-plugin_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Verbinden met verborgen netwerk</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Naam (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Soort beveiliging</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmasker</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primaire dns-server</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Voorvoegsel</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Snelheid</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Bezig met authenticeren…</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Bezig met verkrijgen van ip-adres…</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbonden</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislukt</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Bezig met verkrijgen van adres…</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Bekabeld netwerk: %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Draadloos netwerk: %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Geen netwerkkabel aangesloten</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP-conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Bekabelde verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Bekabelde verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Draadloze verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Draadloze verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netwerk uitschakelen</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netwerkinstellingen</translation>
    </message>
</context>
</TS>
